@@ -55,6 +55,7 @@ assign_peptide_type <- function(data,
                                 last_aa = last_aa,
                                 aa_after = aa_after) {
   data %>%
+    dplyr::distinct({{ aa_before }}, {{ last_aa }}, {{ aa_after }}) %>%
     dplyr::mutate(N_term_tryp = dplyr::if_else({{ aa_before }} == "" |
       {{ aa_before }} == "K" |
       {{ aa_before }} == "R",
@@ -72,5 +73,10 @@ assign_peptide_type <- function(data,
       .data$N_term_tryp + .data$C_term_tryp == 1 ~ "semi-tryptic",
       .data$N_term_tryp + .data$C_term_tryp == 0 ~ "non-tryptic"
     )) %>%
-    dplyr::select(-.data$N_term_tryp, -.data$C_term_tryp)
+    dplyr::select(-.data$N_term_tryp, -.data$C_term_tryp) %>%
+    dplyr::right_join(data, by = c(
+      rlang::as_name(rlang::enquo(aa_before)),
+      rlang::as_name(rlang::enquo(last_aa)),
+      rlang::as_name(rlang::enquo(aa_after))
+    ))
 }
