@@ -8,6 +8,9 @@
 #' cross-referenced database provide the database name with the prefix "xref_", e.g. `"xref_pdb"`)
 #' @param batchsize a numeric value that specifies the number of proteins processed in a single
 #' single query. Default and max value is 200.
+#' @param max_tries a numeric value that specifies the number of times the function tries to download
+#' the data in case an error occurs.
+#' @param timeout a numeric value that specifies the maximum request time per try. Default is 20 seconds.
 #' @param show_progress a logical value that determines if a progress bar will be shown. Default
 #' is TRUE.
 #'
@@ -53,6 +56,8 @@ fetch_uniprot <-
              "xref_pdb"
            ),
            batchsize = 200,
+           max_tries = 10,
+           timeout = 20,
            show_progress = TRUE) {
     if (!curl::has_internet()) {
       message("No internet connection.")
@@ -73,16 +78,16 @@ fetch_uniprot <-
     non_conform_ids <- uniprot_ids[!id_test]
     # if non_conform_ids contain IDs they are extracted and fetched.
     contains_valid_id <- non_conform_ids[stringr::str_detect(non_conform_ids,
-      pattern = "[OPQ][0-9][A-Z0-9]{3}[0-9]|[A-NR-Z][0-9]([A-Z][A-Z0-9]{2}[0-9]){1,2}"
+      pattern = "(?<![:alnum:])[OPQ][0-9][A-Z0-9]{3}[0-9]|[A-NR-Z][0-9]([A-Z][A-Z0-9]{2}[0-9]){1,2}(?![:alnum:])"
     )]
 
     uniprot_ids_contain_valid <- uniprot_ids[stringr::str_detect(uniprot_ids,
-      pattern = "[OPQ][0-9][A-Z0-9]{3}[0-9]|[A-NR-Z][0-9]([A-Z][A-Z0-9]{2}[0-9]){1,2}"
+      pattern = "(?<![:alnum:])[OPQ][0-9][A-Z0-9]{3}[0-9]|[A-NR-Z][0-9]([A-Z][A-Z0-9]{2}[0-9]){1,2}(?![:alnum:])"
     )]
 
     valid_id_annotations <- tibble::tibble(input_id = contains_valid_id) %>%
       dplyr::mutate(accession = stringr::str_extract_all(.data$input_id,
-        pattern = "[OPQ][0-9][A-Z0-9]{3}[0-9]|[A-NR-Z][0-9]([A-Z][A-Z0-9]{2}[0-9]){1,2}"
+        pattern = "(?<![:alnum:])[OPQ][0-9][A-Z0-9]{3}[0-9]|[A-NR-Z][0-9]([A-Z][A-Z0-9]{2}[0-9]){1,2}(?![:alnum:])"
       )) %>%
       tidyr::unnest("accession") %>%
       dplyr::distinct()
@@ -90,7 +95,7 @@ fetch_uniprot <-
     uniprot_ids_filtered <- unique(c(uniprot_ids_filtered, valid_id_annotations$accession))
 
     non_identifiable_id <- non_conform_ids[!stringr::str_detect(non_conform_ids,
-      pattern = "[OPQ][0-9][A-Z0-9]{3}[0-9]|[A-NR-Z][0-9]([A-Z][A-Z0-9]{2}[0-9]){1,2}"
+      pattern = "(?<![:alnum:])[OPQ][0-9][A-Z0-9]{3}[0-9]|[A-NR-Z][0-9]([A-Z][A-Z0-9]{2}[0-9]){1,2}(?![:alnum:])"
     )]
 
     if (length(non_identifiable_id) != 0) {
@@ -125,7 +130,13 @@ They were fetched and the original input ID can be found in the "input_id" colum
         collapsed_columns
       ))
 
-      query <- try_query(query_url, progress = FALSE, show_col_types = FALSE)
+      query <- try_query(query_url,
+        max_tries = max_tries,
+        timeout = timeout,
+        silent = FALSE,
+        progress = FALSE,
+        show_col_types = FALSE
+      )
 
       if (show_progress == TRUE) {
         pb$tick()
@@ -147,6 +158,9 @@ They were fetched and the original input ID can be found in the "input_id" colum
 
       message("The following IDs have not been retrieved correctly.")
       message(paste0(utils::capture.output(error_table), collapse = "\n"))
+      if (any(stringr::str_detect(error_table$error, pattern = "Timeout"))) {
+        message('Consider increasing the "timeout" or "max_tries" argument. \n')
+      }
     }
 
     # only keep data in output and transform to data.frame
@@ -184,13 +198,13 @@ They were fetched and the original input ID can be found in the "input_id" colum
     new_ids <- new$new
 
     if (length(new_ids) == 0) {
-        original_ids <- data.frame(input_id = uniprot_ids_contain_valid) %>%
-          dplyr::left_join(valid_id_annotations, by = "input_id") %>%
-          dplyr::mutate(accession = ifelse(is.na(.data$accession), .data$input_id, .data$accession))
+      original_ids <- data.frame(input_id = uniprot_ids_contain_valid) %>%
+        dplyr::left_join(valid_id_annotations, by = "input_id") %>%
+        dplyr::mutate(accession = ifelse(is.na(.data$accession), .data$input_id, .data$accession))
 
-        result <- result %>%
-          dplyr::right_join(original_ids, by = "accession") %>%
-          dplyr::relocate(.data$accession, .data$input_id)
+      result <- result %>%
+        dplyr::right_join(original_ids, by = "accession") %>%
+        dplyr::relocate("accession", "input_id")
 
       return(result)
     }
@@ -200,7 +214,13 @@ They were fetched and the original input ID can be found in the "input_id" colum
       collapsed_columns
     ))
 
-    new_result <- try_query(new_query_url, progress = FALSE, show_col_types = FALSE)
+    new_result <- try_query(new_query_url,
+      max_tries = max_tries,
+      timeout = timeout,
+      silent = FALSE,
+      progress = FALSE,
+      show_col_types = FALSE
+    )
     # If a problem occurs at this step NULL is returned.
     if (!methods::is(new_result, "data.frame")) {
       message(new_result)
@@ -222,7 +242,7 @@ They were fetched and the original input ID can be found in the "input_id" colum
 
     result <- result %>%
       dplyr::right_join(original_ids, by = "accession") %>%
-      dplyr::relocate(.data$accession, .data$input_id)
+      dplyr::relocate("accession", "input_id")
 
     result
   }
